@@ -1,5 +1,5 @@
 # ************************************************************************* 
-# Copyright (c) 2014, SUSE LLC
+# Copyright (c) 2014-2015, SUSE LLC
 # 
 # All rights reserved.
 # 
@@ -200,6 +200,13 @@ set( 'DOCHAZKA_LDAP_TEST_UID_EXISTENT', 'I_exist_in_local_LDAP' );
 #     a non-existent UID for LDAP testing (t/201-LDAP.t)
 set( 'DOCHAZKA_LDAP_TEST_UID_NON_EXISTENT', 'I_do_NOT_exist_in_local_LDAP' );
 
+# DOCHAZKA_LDAP_POPULATE_MATRIX
+#     set of key => value pairs where key is Employee object property and value
+#     is the matching LDAP property; used to populate employee objects with
+#     values from LDAP (do *not* include nick mapping here - use
+#     DOCHAZKA_LDAP_NICK_MAPPING for that)
+set( 'DOCHAZKA_LDAP_POPULATE_MATRIX', {} );
+
 # DOCHAZKA_REST_SESSION_EXPIRATION_TIME
 #     number of seconds after which a session will be considered stale
 set( 'DOCHAZKA_REST_SESSION_EXPIRATION_TIME', 3600 );
@@ -224,6 +231,13 @@ set( 'DOCHAZKA_PROFILE_EDITABLE_FIELDS', {
 #     overly huge result sets)
 set( 'DOCHAZKA_INTERVAL_SELECT_LIMIT', undef );
 
+# DOCHAZKA_EMPLOYEE_MINIMAL_FIELDS
+#     list of fields to include in "GET employee/eid/:eid/minimal" and
+#     "GET employee/nick/:nick/minimal" and "GET employee/sec_id/:sec_id/minimal"
+set( 'DOCHAZKA_EMPLOYEE_MINIMAL_FIELDS', [ 
+    qw( sec_id nick fullname email eid supervisor )
+] );
+
 # -----------------------------------
 # DO NOT EDIT ANYTHING BELOW THIS LINE
 # -----------------------------------
