@@ -1,5 +1,5 @@
 # ************************************************************************* 
-# Copyright (c) 2014, SUSE LLC
+# Copyright (c) 2014-2015, SUSE LLC
 # 
 # All rights reserved.
 # 
@@ -40,13 +40,14 @@ use strict;
 use warnings;
 
 use App::CELL qw( $CELL $log $core $meta $site );
-use App::Dochazka qw( $today init_timepiece );
+use App::Dochazka::Common qw( $today init_timepiece );
 use App::Dochazka::REST::ACL qw( 
     check_acl_context 
     acl_check_is_me 
     acl_check_is_my_report 
 );
 use App::Dochazka::REST::ConnBank qw( conn_status );
+use App::Dochazka::REST::LDAP qw( populate_employee );
 use App::Dochazka::REST::Model::Activity;
 use App::Dochazka::REST::Model::Employee qw( 
     list_employees_by_priv 
@@ -963,6 +964,11 @@ sub handler_post_employee_nick {
         $func = $emp ? 'update_employee' : 'insert_employee';
         return $fail unless shared_employee_acl_part1( $self, $emp );  # additional ACL checks
         $self->nullify_declared_status;
+    } else {
+        $self->mrest_declare_status( code => 400, 
+            explanation => 'DISPATCH_PROP_MISSING_IN_ENTITY', args => [ 'nick' ],
+        );
+        return $fail;
     }
     if ( $func eq 'update_employee' ) {
         delete $context->{'request_entity'}->{'nick'};
@@ -1053,6 +1059,134 @@ sub handler_get_employee_eid {
     return shared_get_employee( $self, $pass, 'EID', $self->context->{'mapping'}->{'eid'} );
 }
 
+
+=head3 handler_get_employee_ldap
+
+Handler for 'GET employee/nick/:nick/ldap' resource.
+
+=cut
+
+sub handler_get_employee_ldap {
+    my ( $self, $pass ) = @_;
+    $log->debug( "Entering " . __PACKAGE__ . "::handler_get_employee_ldap" ); 
+
+    my $context = $self->context;
+    my $nick = $self->context->{'mapping'}->{'nick'};
+
+    if ( $pass == 1 ) {
+        if ( ! $site->DOCHAZKA_LDAP ) {
+            $self->mrest_declare_status( 
+                'code' => 501, 
+                'explanation' => 'LDAP not configured on this server' 
+            );
+            return 0;
+        } else {
+            $log->debug( "DOCHAZKA_LDAP site param is true: LDAP is enabled" );
+        }
+        my $emp = App::Dochazka::REST::Model::Employee->spawn( 'nick' => $nick );
+        $context->{'stashed_nick'} = $nick;
+        my $status = populate_employee( $emp );
+        return 0 unless $status->ok;
+        $context->{'stashed_ldap_status'} = $status;
+        $context->{'stashed_employee_object'} = $emp;
+        return 1;
+    }
+
+    return $CELL->status_ok( 'DOCHAZKA_LDAP_LOOKUP', payload => $context->{'stashed_employee_object'} );
+}
+
+
+=head3 handler_put_employee_ldap
+
+Handler for 'PUT employee/nick/:nick/ldap' resource.
+
+=cut
+
+sub handler_put_employee_ldap {
+    my ( $self, $pass ) = @_;
+    $log->debug( "Entering " . __PACKAGE__ . "::handler_put_employee_ldap" ); 
+
+    my $context = $self->context;
+
+    if ( $pass == 1 ) {
+        return $self->handler_get_employee_ldap( $pass );
+    }
+
+    my $nick = $context->{'stashed_nick'};
+
+    # Get the employee object corresponding to the nick provided by the user.
+    my $emp = $context->{'stashed_employee_object'};
+    if ( ! $emp ) {
+        $self->mrest_declare_status( 'code' => 404, 'explanation' => "Nick ->$nick<- not found in LDAP" );
+        return $CELL->status_not_ok;
+    }
+
+    my $status = $emp->load_by_nick( $context->{'dbix_conn'}, $emp->nick );
+    if ( $status->ok ) {
+        # employee exists; update it
+        my $eid = $status->payload->eid;
+        $emp->eid( $eid );
+        return $emp->update( $context );
+    } elsif ( $status->level eq 'NOTICE' and $status->code eq 'DISPATCH_NO_RECORDS_FOUND' ) {
+        return $emp->insert( $context );
+    }
+    return $status;
+}
+
+
+=head3 handler_get_employee_minimal
+
+Handler for 'GET employee/eid/:eid/minimal' resource.
+Handler for 'GET employee/nick/:nick/minimal' resource.
+Handler for 'GET employee/sec_id/:sec_id/minimal' resource.
+
+=cut
+
+sub handler_get_employee_minimal {
+    my ( $self, $pass ) = @_;
+    $log->debug( "Entering " . __PACKAGE__ . "::handler_get_employee_minimal" ); 
+
+    if ( $pass == 1 ) {
+
+        # determine key and value
+        my $resource_name = $self->context->{'resource_name'};
+        my ( $key, $value );
+        if ( $resource_name eq 'employee/eid/:eid/minimal' ) {
+            $key = 'EID';
+            $value = $self->context->{'mapping'}->{'eid'};
+        } elsif ( $resource_name eq 'employee/nick/:nick/minimal' ) { 
+            $key = 'nick';
+            $value = $self->context->{'mapping'}->{'nick'};
+        } elsif ( $resource_name eq 'employee/sec_id/:sec_id/minimal' ) {
+            $key = 'sec_id';
+            $value = $self->context->{'mapping'}->{'sec_id'};
+        }
+
+        # ACL check
+        my $priv = $self->context->{'current_priv'};
+        if ( $priv eq 'passerby' ) {
+            if ( ! acl_check_is_me( $self, ( lc $key ) => $value ) ) { 
+                $self->mrest_declare_status( code => 403, explanation => "DISPATCH_KEEP_TO_YOURSELF" );
+                return 0;
+            }
+        }
+
+        # populate $emp
+        my $emp = shared_first_pass_lookup( $self, $key, $value );
+        return 0 unless $emp;
+
+        # populate stashed value
+        foreach my $prop ( @{ $site->DOCHAZKA_EMPLOYEE_MINIMAL_FIELDS } ) {
+            $self->context->{'stashed_value'}->{ $prop } = $emp->get( $prop );
+        }
+
+        return 1;
+    }
+
+    return $CELL->status_ok( 'DOCHAZKA_EMPLOYEE_MINIMAL', payload => $self->context->{'stashed_value'} );
+}
+
+
 =head3 handler_get_employee_eid_team
 
 Handler for 'GET employee/eid/:eid/team'
